==> vcs_plugin-0.0.2.tar.gz: lib/vcs_plugin.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class VcsPlugin {
  static const MethodChannel _channel =
      const MethodChannel('ecp_sync_plugin');

  static VcsPlugin _instance;

  factory VcsPlugin() {
    if (_instance == null) {
      final MethodChannel methodChannel =
      const MethodChannel('ecp_sync_plugin');
      final EventChannel eventChannel =
      const EventChannel('ecp_sync_plugin_Progress');
      _instance = VcsPlugin.private(methodChannel, eventChannel);
    }
    return _instance;
  }

  final MethodChannel _methodChannel;
  final EventChannel _eventChannel;

  Stream<Map> _onBatteryStateChanged;

  VcsPlugin.private(this._methodChannel, this._eventChannel);

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Future<String> get setDaySeven async {
    final String version = await _channel.invokeMethod('setDaySeven');
    return version;
  }

  Future<String> get setDaySevenDefault async {
    final String version = await _channel.invokeMethod('setDaySevenDefault');
    return version;
  }

  Stream<Map> get onBatteryStateChanged {
    if (_onBatteryStateChanged == null) {
      _onBatteryStateChanged = _eventChannel
          .receiveBroadcastStream()
          .map((dynamic event) => _parseBatteryState(event));
    }
    return _onBatteryStateChanged;
  }

  Map _parseBatteryState(Map state) {
    print("_parseBatteryState : $state");

    /*switch (state) {
      case 'full':
        return BatteryState.full;
      case 'charging':
        return BatteryState.charging;
      case 'discharging':
        return BatteryState.discharging;
      default:
        throw ArgumentError('$state is not a valid BatteryState.');
    }*/

    //Map valueMap = json.decode(state);

    return state;
  }
}

==> vcs_plugin-0.0.4.tar.gz: lib/vcs_plugin.dart <==
import 'dart:async';

import 'package:flutter/services.dart';

class VcsPlugin {
  static const MethodChannel _channel =
      const MethodChannel('ecp_sync_plugin_dev');

  static VcsPlugin _instance;

  factory VcsPlugin() {
    if (_instance == null) {
      final MethodChannel methodChannel =
          const MethodChannel('ecp_sync_plugin_dev');
      final EventChannel eventChannel =
          const EventChannel('ecp_sync_plugin_Progress_dev');
      _instance = VcsPlugin.private(methodChannel, eventChannel);
    }
    return _instance;
  }

  final MethodChannel _methodChannel;
  final EventChannel _eventChannel;

  Stream<Map> _onBatteryStateChanged;

  VcsPlugin.private(this._methodChannel, this._eventChannel);

  static Future<String> get platformVersion async {
    final String version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  Future<String> get setDaySeven async {
    final String version = await _channel.invokeMethod('setDaySeven');
    return version;
  }

  Future<String> get setDaySevenDefault async {
    final String version = await _channel.invokeMethod('setDaySevenDefault');
    return version;
  }

  Stream<Map> get onBatteryStateChanged {
    if (_onBatteryStateChanged == null) {
      _onBatteryStateChanged = _eventChannel
          .receiveBroadcastStream()
          .map((dynamic event) => _parseBatteryState(event));
    }
    return _onBatteryStateChanged;
  }

  Map _parseBatteryState(Map state) {
    print("_parseBatteryState : $state");

    /*switch (state) {
      case 'full':
        return BatteryState.full;
      case 'charging':
        return BatteryState.charging;
      case 'discharging':
        return BatteryState.discharging;
      default:
        throw ArgumentError('$state is not a valid BatteryState.');
    }*/

    //Map valueMap = json.decode(state);

    return state;
  }
}
